@@ -390,6 +390,38 @@ class ConfigurableInstance:
                     ConfiguredAction(getattr(self, method_name))
                 )
 
+    def execute_action(self, action: str, *args, **kwargs) -> 'TrackedAction':
+        """
+        Executes an action associated with the instance with the provided args and kwargs.
+
+        :param action: action name to execute (must be a registered method of the instance)
+        :param args: arguments to provide for the execution
+        :param kwargs: keyword arguments to provide for the execution
+        :return: the generated TrackedAction instance
+        """
+        if action not in self.methods_to_register:
+            raise KeyError(f'the method "{action}" is not a registered method of this {self.__class__.__name__} instance')
+        ta = TrackedAction(configuration=getattr(self, action))
+        ta(*args, **kwargs)
+        return ta
+
+    def execute_action_threaded(self, action: str, *args, **kwargs) -> 'ThreadedTrackedAction':
+        """
+        Executes an action in a thread associated with the instance with the provided args and kwargs. This
+        method is non-blocking.
+
+        :param action: action name to execute (must be a registered method of the instance)
+        :param args: arguments to provide for the execution
+        :param kwargs: keyword arguments to provide for the execution
+        :return: the generated ThreadedTrackedAction instance
+        """
+        if action not in self.methods_to_register:
+            raise KeyError(
+                f'the method "{action}" is not a registered method of this {self.__class__.__name__} instance')
+        tta = ThreadedTrackedAction(configuration=getattr(self, action))
+        tta(*args, **kwargs)
+        return tta
+
 
 def ensure_triggered(fn: Callable):
     """a decorator which ensures that the instance has been triggered"""
