@@ -8,7 +8,9 @@ import time
 import logging
 import bisect
 import datetime
-from typing import List, Union, Iterable
+
+from typing import List, Union, Iterable, Callable
+
 from .timepoint import ActionTimePoint
 from .action import Action, ConfiguredAction
 from .sequencing import ConfiguredSequence
@@ -581,3 +583,63 @@ class SamplingScheduler(InstanceRegistry):
                     )
                 f.write('\n')
 
+
+class ExecuteOnTimePoints(ConfiguredAction):
+    def __init__(self,
+                 action: Callable,
+                 *timepoints,
+                 configuration_name: str = None,
+                 enabled: bool = True,
+                 **kwargs,
+                 ):
+        """
+        Class for executing an action on the specified timepoints. When the action is triggered, the time point list
+        of the instance will be checked against the currently executing timepoint name. If the condition matches,
+        the action will be executed.
+
+        :param action: action to execute when triggered and the conditions are met
+        :param timepoints: time point numbers to execute on
+        :param configuration_name: name for the configuration
+        :param enabled: whether the action should be enabled (use this to disable any execution)
+        :param kwargs: kwarg pass through to ConfiguredAction
+        """
+        ConfiguredAction.__init__(
+            self,
+            action=action,
+            configuration_name=configuration_name,
+            **kwargs,
+        )
+        self.timepoints: List[int] = list(timepoints)
+        self.enabled: bool = enabled
+
+    @property
+    def regex(self):
+        """regex pattern for matching timepoint names"""
+        value_pattern = "|".join([str(val) for val in self.timepoints])
+        return re.compile(
+            f'Time Point #({value_pattern})'
+        )
+
+    def evaluate_condition(self) -> bool:
+        """Performs the logic check to determine whether the action should be executed"""
+        # todo make this check specific to the parent timepoint
+        #   currently if any running timepoint name matches any timepoint numbers in the the instance,
+        #   True will be returned
+        if self.enabled is False:
+            logger.debug(f'{self.name} disabled, bypassing logic checks')
+            return False
+        timepoints = [
+            timepoint
+            for sched in SamplingScheduler.class_registry
+            for timepoint in sched.time_points
+            if timepoint.status_code == 2
+        ]
+        if len(timepoints) == 0:
+            logger.debug(f'{self.name} no active timepoints, bypassing')
+            return False  # todo consider what to do in this case
+        tp = timepoints[0]
+        if self.regex.search(tp.name):
+            logger.debug(f'{self.name} timepoint number match, performing action')
+            return True
+        logger.debug(f'{self.name} no conditions met, bypassing')
+        return False
