@@ -2,7 +2,7 @@ import logging
 import time
 import unittest
 from hein_control.action import Action, EvalAction, TrackedDecision, ConfiguredAction, ConfiguredDecision, \
-    ThreadedTrackedAction, TrackedAction, ConfiguredActionList
+    ThreadedTrackedAction, TrackedAction, ConfiguredActionList, ConfigurableInstance
 from hein_control.action.operators import execute_sequence_actions, run_automation, decision
 from hein_control.mixin import Configuration, Status
 
@@ -656,3 +656,48 @@ class TestOperators(unittest.TestCase):
                          tracked_decision.action_return)
         self.assertEqual(('one!', {'kwargs': 'kwargs for one'}),
                          tracked_conf_log_1.action_return)
+
+
+class RegMethodsInstance(ConfigurableInstance):
+    methods_to_register = [
+        'inst_action_one',
+        'inst_action_two',
+    ]
+
+    def inst_action_one(self):
+        return 'banana'
+
+    def inst_action_two(self):
+        return 'split'
+
+
+class TestConfigurableInstance(unittest.TestCase):
+    @classmethod
+    def setUpClass(cls) -> None:
+        cls.test_inst = RegMethodsInstance()
+
+    def test_registered(self):
+        """tests that methods are registered"""
+        self.assertTrue(isinstance(self.test_inst.inst_action_one, ConfiguredAction))
+        self.assertTrue(isinstance(self.test_inst.inst_action_two, ConfiguredAction))
+
+    def test_blocking_exec(self):
+        """tests blocking execution"""
+        def execute_and_test(action, result):
+            ta = self.test_inst.execute_action(action)
+            self.assertEqual(ta.status_code, 3)
+            self.assertEqual(ta.action_return, result)
+        execute_and_test('inst_action_one', 'banana')
+        execute_and_test('inst_action_two', 'split')
+
+    def test_nonblocking_exec(self):
+        """tests threaded execution of actions"""
+        def execute_and_test(action, result):
+            tta = self.test_inst.execute_action_threaded(action)
+            tta.wait_for_completion()
+            self.assertEqual(tta.status_code, 3)
+            self.assertEqual(tta.action_return, result)
+
+        execute_and_test('inst_action_one', 'banana')
+        execute_and_test('inst_action_two', 'split')
+
